package main

import (
	"log"
	"os"

	"github.com/knadh/koanf"
	"github.com/knadh/koanf/parsers/toml"
	"github.com/knadh/koanf/providers/confmap"
	"github.com/knadh/koanf/providers/file"
	//"git.kemonine.info/PiFrame/ui"
)

const (
	CONFIG_FILE_PATH              = "/etc/default/pf.toml"
	CONFIG_KEY_SLIDESHOW_DURATION = "slideshow.duration"
	CONFIG_KEY_HDMI_OFF           = "hdmi.off"
	CONFIG_KEY_HDMI_ON            = "hdmi.on"
	CONFIG_KEY_ALBUMS_ROOT        = "albums.root"
	CONFIG_KEY_ALBUMS_SELECTED    = "albums.selected"
)

const (
	DEFAULT_SLIDESHOW_DURATION = "300s"
	DEFAULT_HDMI_OFF           = "*-*-* 00:00:00"
	DEFAULT_HDMI_ON            = "*-*-* 06:00:00"
	DEFAULT_ALBUMS_ROOT        = "/tank/pictures"
	DEFAULT_ALBUM_SELECTED     = "/"
)

func main() {
	// Main config variable
	var pfConfig = koanf.New(".")

	// Setup some defaults
	pfConfig.Load(confmap.Provider(map[string]interface{}{
		CONFIG_KEY_SLIDESHOW_DURATION: DEFAULT_SLIDESHOW_DURATION,
		CONFIG_KEY_HDMI_OFF:           DEFAULT_HDMI_OFF,
		CONFIG_KEY_HDMI_ON:            DEFAULT_HDMI_ON,
		CONFIG_KEY_ALBUMS_ROOT:        DEFAULT_ALBUMS_ROOT,
		CONFIG_KEY_ALBUMS_SELECTED:    []string{DEFAULT_ALBUM_SELECTED},
	}, "."), nil)

	_, err := os.Stat(CONFIG_FILE_PATH)
	if err != nil {
		if os.IsNotExist(err) {
			log.Printf("%s does not exist, USING DEFAULTS", CONFIG_FILE_PATH)
		} else {
			if errConfigFile := pfConfig.Load(file.Provider(CONFIG_FILE_PATH), toml.Parser()); errConfigFile != nil {
				log.Fatalf("Error loading config: %s", err)
			}
		}
	}

	// slideshowDuration := pfConfig.Duration(CONFIG_KEY_SLIDESHOW_DURATION)
	// hdmiOff := pfConfig.String(CONFIG_KEY_HDMI_OFF)
	// hdmiOn := pfConfig.String(CONFIG_KEY_HDMI_ON)
	// albumsRoot := pfConfig.String(CONFIG_KEY_ALBUMS_ROOT)
	// albumsSelected := pfConfig.Strings(CONFIG_KEY_ALBUMS_SELECTED)

	//ui.Slideshow()
	//ui.ConfigGui()
}
